#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.1.3
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 12.99.2
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-gui-common-devel >= 4.1.0
BuildRequires:	qubes-db-devel
BuildRequires:	xen-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan-xen
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-server-Xorg
Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make BACKEND_VMM=xen appvm

%install
rm -rf $RPM_BUILD_ROOT
make install install-xfce DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER=%{pa_ver}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%{_libdir}/libxf86-qubes-common.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
/etc/profile.d/qubes-session.sh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/qubes-keymap.sh
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
%config /etc/sysconfig/desktop
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/tmpfiles.d/qubes-session.conf
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/50-xfce-desktop.sh

%changelog
* Fri Sep 06 2019 Qubes OS Team <qubes-devel@groups.google.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b5cfc13
- version 4.1.3

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 62e9de5
- Merge remote-tracking branch 'origin/pr/70'

* Thu Sep 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3c14548
- spec: handle newer pulseaudio for Fedora 31+

* Thu Sep 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2586964
- Add pulseaudio-12.99.2 symlinked headers

* Mon Jul 01 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 36c1d98
- version 4.1.2

* Mon Jul 01 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 96d1d1d
- debian: add Build-Depends: lsb-release

* Mon Jun 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 98f870e
- Build package for dom0 too

* Mon Jun 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ea6af08
- Merge remote-tracking branch 'origin/pr/66'

* Mon Jun 17 2019 Laurent <haarlaurent67@hotmail.fr> - 597ea45
- Update PKGBUILD

* Mon Jun 10 2019 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - 7a5ffa8
- add modargs for target domid and sink/source descr strings

* Sat Jun 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5e0c00e
- version 4.1.1

* Fri May 31 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - de3b133
- spec: better use rmdir and check if exist for /etc/init.d

* Fri May 31 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - fcbb457
- spec: ensure we remove empty /etc/inid.d folder

* Fri May 31 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9d479d5
- Init script qubes-gui-agent is not needed anymore

* Fri Apr 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c864859
- travis: add fc30, switch to xenial

* Fri Apr 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ff9edf4
- Convert qubes-change-keyboard-layout to python3

* Thu Mar 14 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 258eccf
- video-dummy: fix off by one error in memory size check

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2986893
- version 4.1.0

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 40f7b76
- rpm,deb: add xen devel to build requirements

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8dcccad
- travis: update to R4.1

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a4c8cfb
- Merge remote-tracking branch 'origin/pr/27'

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 703e8f5
- Merge branch 'grant-refs'

* Fri Mar 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8b8b883
- version 4.0.21

* Fri Mar 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8c4735d
- Indentation fix

* Fri Mar 01 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86b5b8d
- Fix GCC9 warning about size in strncpy

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8827d60
- Increase gntalloc limit

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8e29dc9
- xf86-video-dummy: fix FBBase release

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ef35181
- xf86-video-dummy: fix compiler warning

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1114286
- rpm/deb: bump required qubes-gui-common-devel version

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 08a9d4d
- Use CFLAGS/LDFLAGS set by rpm

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 775bbcf
- vmside: handle memory allocation error

* Fri Feb 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d3cbb6d
- Merge remote-tracking branch 'origin/pr/34' into grant-refs

* Fri Jan 18 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0005614
- Drop /etc/X11/Xwrapper.config

* Fri Jan 11 2019 Olivier MEDOC <o_medoc@yahoo.fr> - d456f65
- archlinux: switch to using icon-sender with python3

* Fri Jan 04 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bc54e44
- version 4.0.20

* Sun Dec 23 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0104aaf
- Merge remote-tracking branch 'qubesos/pr/59'

* Sat Dec 22 2018 Frédéric Pierret (fepitre) <frederic.epitre@orange.fr> - e694db7
- spec: fix missing abi version requirement

* Tue Nov 27 2018 Olivier MEDOC <o_medoc@yahoo.fr> - 01ea25f
- fix install path to follow archlinux packaging guidelines

* Wed Nov 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9f15169
- version 4.0.19

* Wed Nov 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1308652
- Merge branch 'logind'

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aca4099
- vmside: cleanup calling qubes-run-xorg, terminate it on service stop

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - db9e515
- qubes-run-xorg: fix one more place with hardcoded 'user'

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6425ba2
- Fix X11 session registration in logind

* Tue Nov 13 2018 Wojtek Porczyk <woju@invisiblethingslab.com> - d222e16
- qubes-run-xorg: add configurable videoram overhead

* Wed Oct 31 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e9b972e
- Fix qubes-keymap script permissions

* Mon Oct 29 2018 Duncan X. Simpson <virtualdxs@gmail.com> - 46aec51
- Bump xorg-server version

* Mon Oct 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0abccf0
- version 4.0.18

* Sat Oct 27 2018 Duncan X. Simpson <virtualdxs@gmail.com> - 4efb79d
- Fix python-xcffib dependency

* Tue Oct 23 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 974b13d
- Merge branch 'composite-automatic'

* Tue Oct 23 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3187ffb
- gui-agent: switch to automatic composition mode, fix in-vm screenshots

